@@ -4,8 +4,8 @@
 # adjust: smoothing parameter (adjust = 1/c in old code)
 
 densityPlot <-
-function(A, xscale=24, add=FALSE, rug=FALSE,
-    n.grid=128, kmax = 3, adjust = 1, ...)  {
+function(A, xscale=24, add=FALSE, rug=FALSE, 
+    n.grid=128, kmax = 3, adjust = 1, ylim, xlab="Time", ylab="Density", ...)  {
 
   bw <- getBandWidth(A, kmax=kmax) / adjust
   if(is.na(bw))
@@ -15,10 +15,11 @@ function(A, xscale=24, add=FALSE, rug=FALSE,
   densA <- densityFit(A, xx, bw)
   xsc <- if(is.na(xscale)) 1 else xscale / (2*pi)
   toPlot <- cbind(x = xx * xsc, y = densA / xsc)
-  
+  if(missing(ylim))
+    ylim <- c(0, max(toPlot[,'y']))
   if(!add)  {
     plot(toPlot, type='n', #las=1, 
-      ylim=c(0, max(toPlot[,'y'])), xlab="Time", ylab="Density", xaxt='n', ...)
+      ylim=ylim, xlab=xlab, ylab=ylab, xaxt='n', ...)
     if(is.na(xscale)) {
       axis(1, at=c(0, pi/2, pi, 3*pi/2, 2*pi),
         labels=c("0", expression(pi/2), expression(pi),
